import type { PageParams, PageResult } from '@/types/global'
import type { BannerItem, CategoryItem, GuessItem, HotItem } from '@/types/home'
import { http } from '@/utils/http'

/**
 * 获取首页轮播图
 * @param distributionSite - 广告区域展示位置: 1 为首页（默认值）; 2 为商品分类页
 * @returns 轮播图数据
 */
export const getHomeBanner = (distributionSite = 1) => {
  return http<BannerItem[]>({
    url: '/home/banner',
    method: 'GET',
    data: {
      distributionSite,
    },
  })
}

/**
 * 获取首页分类
 * @returns 分类数据
 */
export const getCategory = () => {
  return http<CategoryItem[]>({
    url: '/home/category/mutli',
    method: 'GET',
  })
}

/**
 * 获取首页热门商品
 * @returns 热门商品数据
 */
export const getHomeHot = () => {
  return http<HotItem[]>({
    url: '/home/hot/mutli',
    method: 'GET',
  })
}

/**
 * 获取首页猜你喜欢
 * @param data - 分页参数
 * @returns 猜你喜欢数据
 */
export const getGuessLike = (data?: PageParams) => {
  return http<PageResult<GuessItem>>({
    url: '/home/goods/guessLike',
    method: 'GET',
    data,
  })
}
